@@ -122,21 +122,94 @@ class Population(Talker):
         '''
         Create a new population by adding two together:
 
-            big = one + another
+            `bigger = this + other`
 
         Parameters
         ----------
         other : Population
             The population to be tacked onto this one.
+
+        Returns
+        -------
+        bigger : Population
+            A new population, consisting of all the planets
+            in `this` population and some extra ones added
+            from `other`.
+
         '''
 
+        # skip any warnings that pop up
         with warnings.catch_warnings():
             warnings.simplefilter('ignore')
-            table = join(self.standard, other.standard, join_type='outer')
+
+            #  create a new table, joining both together
+            table = join(self.standard,
+                         other.standard,
+                         join_type='outer')
+
+            # create an informative label
             label = f'{self.label} + {other.label}'
 
+        # create and return the new population
         return Population(table, label=label)
 
+    def remove_by_key(self, other, key='tidyname'):
+        '''
+        Create a new population by removing some rows from here:
+
+            `smaller = this - other`
+
+        Parameters
+        ----------
+        other : Population
+            The population of planets to be removed from
+            `this` population to create a new `smaller` one.
+
+        Returns
+        -------
+        smaller : Population
+            A subset of `this` population, where some rows
+            have been removed.
+        '''
+
+        # skip any warnings that pop up
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
+
+            #  create a new table, joining both together
+            table = setdiff(self.standard,
+                            other.standard,
+                            keys=key)
+
+            # create an informative label
+            label = f'{self.label} - {other.label}'
+
+        # create and return the new population
+        return Population(table, label=label)
+
+
+
+    def __sub__(self, other):
+        '''
+        Create a new population by removing some rows from here:
+
+            `smaller = this - other`
+
+        Parameters
+        ----------
+        other : Population
+            The population of planets to be removed from
+            `this` population to create a new `smaller` one.
+
+        Returns
+        -------
+        smaller : Population
+            A subset of `this` population, where some rows
+            have been removed.
+        '''
+        return self.remove_by_key(other)
+
+
     def __getitem__(self, key):
         '''
         Create a subpopulation of planets by indexing, slicing, or masking.
@@ -179,11 +252,27 @@ class Population(Talker):
 
     def create_subset_by_name(self, key):
         '''
-        Pull out a subset of this population,
+        Extract a subset of this population,
         based on one or more planet names.
+
+        Parameters
+        ----------
+        key : strings, list of strings
+            The name of a planet ("GJ1132b")
+            or a list of planet names.
+
+            (All names will be stripped of
+            special characters and converted
+            to lower case before indexing.)
+
+        Returns
+        -------
+        subset : Population
+            A new population containing
+            some subset of the original.
         '''
 
-        # use a string or a list of strings to index the population by name
+        # use a (list of) string(s) to index population by name
         if isinstance(key, str):
             # is it just one name?
             key = clean(key).lower()
@@ -208,10 +297,27 @@ class Population(Talker):
 
     def create_subset_by_hostname(self, key):
         '''
-        Pull out a subset of this population,
-        based on one or more planet names.
+        Extract a subset of this population,
+        based on one or more planet hostnames.
+
+        Parameters
+        ----------
+        key : strings, list of strings
+            The hostname of a planet ("GJ1132")
+            or a list of planet hostnames.
+
+            (All names will be stripped of
+            special characters and converted
+            to lower case before indexing.)
+
+        Returns
+        -------
+        subset : Population
+            A new population containing
+            some subset of the original.
         '''
 
+
         # use a string or a list of strings to index the population by name
         if isinstance(key, str):
             # is it just one name?
@@ -234,6 +340,84 @@ class Population(Talker):
                           label=label,
                           **self.plotkw)
 
+    def create_subset_by_position(self,
+                                  coordinates,
+                                  radius=1*u.arcmin,
+                                  use_proper_motions=False,
+                                  return_indices=False):
+        '''
+        Extract a subset of this population,
+        by performing a spatial cross-match by
+        RA and Dec. This will return all plannets
+        from this population that fall within
+        the specified radius of at least one of
+        the specified coordinates.
+
+        Parameters
+        ----------
+        coordinates : astropy.coordinates.SkyCoord
+            The sky coordinate (RA, Dec) or list
+            of coordinates we want to search for
+            nearby objects.
+
+        radius : astropy.units.Quantity
+            The angular radius around each position
+            that we should include in each search.
+
+        use_proper_motions : bool
+            Should we use available proper motions,
+            embedded in the skycoords, to propagate
+            positions to a shared epoch before
+            cross-matching? Alas, this ability
+            is *not yet implemented*. FIXME!
+
+        return_indices : bool
+            Should we also return the indices
+            of the original coordinates that
+            were matched to existing positions?
+
+        Returns
+        -------
+        subset : Population
+            A new population containing a subset
+            of the original, including *all* planets
+            that fall within the 2D sky search space.
+
+        '''
+
+        if use_proper_motions:
+            raise NotImplementedError('No cross-matching with proper motions yet :-(')
+
+        # create astropy coordinates for this population
+        population_coords = SkyCoord(ra=self.ra, dec=self.dec)
+
+        # do a spatial cross match on the sky
+        #  (idx gives the index into coordinates,
+        #   each corresponding to an entry in population_coords)
+        idx, d2d, d3d = population_coords.match_to_catalog_sky(coordinates)
+
+        # identify which systems are actually close on the sky
+        match = d2d < radius
+
+        # create new populations that are linked by spatial position
+        i_match = match.nonzero()[0]
+        #matched_coordinates = coordinates[idx[i_match]]
+        subset = self.standard[i_match]
+
+        # define a meaningful label
+        label = f'Spatial Cross-Match ({len(coordinates)} positions, {radius} radius)'
+
+        # create that new sub-population
+        new_population = Population(standard=subset,
+                                    label=label,
+                                    **self.plotkw)
+
+        # choose what to return
+        if return_indices:
+            i_from_original_coordinates = idx[i_match]
+            return new_population, i_from_original_coordinates
+        else:
+            return new_population
 
     def __getattr__(self, key):
         '''
@@ -1300,3 +1484,35 @@ class PredefinedPopulation(Population):
                             format='ascii.ecsv',
                             overwrite=True )
         self.speak(f'Saved a standardized text table to {self.standard_path}')
+
+    def create_table(self, desired_columns=['name',
+                                            'radius', 'relative_insolation',
+                                            'stellar_radius', 'stellar_teff',
+                                            'ra', 'dec', 'distance']):
+        '''
+        Create an astropy table based on this population,
+        using a subset of columns, which may include ones
+        that have been calculated as Population properties.
+
+        Parameters
+        ----------
+        desired_columns : list
+            The columns you want to include. Anything that
+            can be accessed via Population.??? can be provided
+            here as a string.
+
+        Returns
+        -------
+        table : astropy.table.Table
+            A table, with those columns, in the same order
+            as the Population itself.
+        '''
+        # FIXME! need to add method support for arguments
+
+        # create a dictionary with the desired columns
+        d = {c:getattr(self, c) for c in desired_columns}
+
+        # turn that into an astropy Table
+        t = Table(d)
+
+        return t
