@@ -3,7 +3,7 @@ from .Exoplanets import *
 from .TOI import *
 from .TOISubsets import *
 from .SolarSystem import *
-from .ExoplanetSubsets import *
+from .ExoplanetsSubset import *
 from .summary import *
 from .column_descriptions import *
 from .collections import *
